Learn R Programming

BiDAG (version 2.0.0)

compact2full: Deriving an adjecency matrix of a full DBN

Description

This function transforms a compact 2-slice adjacency matrix of DBN into full T-slice adjacency matrix

Usage

compact2full(DBNmat, n.dynamic, n.slices, n.static = 0)

Arguments

DBNmat

a square matrix, representing initial and transitional structure of a DBN; the size of matrix is 2*n.dynamic+n.static

n.dynamic

integer, number of dynamic variables in one time slice

n.slices

integer, number of slices in an unrolled DBN

n.static

integer, number of static variables

Value

an adjacency matrix of an unrolled DBN

Examples

Run this code
# NOT RUN {
compact2full(DBNmat, n.dynamic=12, n.slices=5, n.static=3)
# }

Run the code above in your browser using DataLab