Learn R Programming

BiDAG (version 2.0.0)

full2compact: Deriving a compact adjacency matrix of a DBN

Description

This function transforms an unrolled adjacency matrix of DBN into a compact representation

Usage

full2compact(DBNmat, n.dynamic, n.static = 0)

Arguments

DBNmat

a square matrix, representing the structure of an unrolled DBN; the size of matrix is n.slices*n.dynamic+n.static; all static variables are assumed to be in the first n.static rows and columns of the matrix

n.dynamic

integer, number of dynamic variables in each time slice

n.static

integer, number of static variables

Examples

Run this code
# NOT RUN {
full2compact(DBNunrolled,n.dynamic=12,n.static=3)
# }

Run the code above in your browser using DataLab