powered by
This function derives an adjacency matrix of a subgraph based on the adjacency matrix of a full graph and a list of nodes
getSubGraph(adj, nodes)
square adjacency matrix with elements in {0,1}, representing a graph
{0,1}
vector of node names of the subgraph; should be a subset of column names of 'adj'
adjacency matrix of a subgraph which includes all 'nodes'
# NOT RUN { getSubGraph(Asiamat,c("E","B","D","X")) # }
Run the code above in your browser using DataLab