powered by
This function derives the adjacency matrix corresponding to a graph object
graph2m(g)
graph, object of class graphNEL (package `graph')
graphNEL
a square matrix whose dimensions are the number of nodes in the graph g, where element [i,j] equals 1 if there is a directed edge from node i to node j in the graph g, and 0 otherwise
[i,j]
1
i
j
g
0
# NOT RUN { Asiagraph<-m2graph(Asiamat) Asia.adj<-graph2m(Asiagraph) # }
Run the code above in your browser using DataLab