powered by
A data frame containing possible interactions between genes from kirp and kirc data sets
kirp
kirc
intSTRING
A data frame with 179 rows and 2 columns; each row represent a possible interaction between two genes