Learn R Programming

BiDAG (version 2.0.2)

iterativeMCMC class: iterativeMCMC class structure

Description

The structure of an object of S3 class iterativeMCMC.

Arguments

Details

An object of class iterativeMCMC is a list containing at least the following components:

  • DAG: adjacency matrix of a maximum scoring DAG found/sampled in MCMC.

  • CPDAG: adjacency matrix representing equivalence class of a maximum scoring DAG found/sampled in MCMC.

  • score: score of a maximum scoring DAG found/sampled in MCMC.

  • maxorder: order of a maximum scoring DAG found/sampled in MCMC.

  • maxtrace: a list of maximum score graphs uncovered at each expansion of the search space; their scores and orders

  • info: a list containing information about parameters and results of MCMC

  • trace: a vector containing log-scores of sampled DAGs

  • startspace: adjacency matrix representing the initial core space where MCMC was ran

  • endspace: adjacency matrix representing the final core space where MCMC was ran

    Optional components:

    • traceadd: list which consists of three elements:

      • incidence: list containg adjacency matrices of sampled DAGs

      • order: list of orders from which the DAGs were sampled

      • orderscores: order log-scores

    • scoretable: object of class scorespace class