Learn R Programming

BiDAG (version 2.0.0)

kich: KICH dataset

Description

Mutation data from TCGA kidney chromophobe cohort (KICH). Mutations are picked according to q-value computed by MutSigCV. Only mutations with q-value of less than 0.05 for any of kidney cancer subtypes (KIRC, KIRP, KICH) are included.

Usage

kich

Arguments

Format

An object of class matrix with 66 rows and 40 columns.

Details

Each variable represents a gene. If in sample i gene j contains a mutation, than j-th element in row i equals 1, and 0 otherwise. The rows are named according to sample names in TCGA. The columns are named according to gene symbols.

References

https://portal.gdc.cancer.gov/

http://firebrowse.org/iCoMut/?cohort=kich

Lawrence, M. et al. Mutational heterogeneity in cancer and the search for new cancer-associated genes. Nature 499, 214-218 (2013).