powered by
This function transforms a compact 2-slice adjacency matrix of DBN into full T-slice adjacency matrix
compact2full(DBNmat, n.dynamic, n.slices, n.static = 0)
a square matrix, representing initial and transitional structure of a DBN; the size of matrix is 2*n.dynamic+n.static
integer, number of dynamic variables in one time slice
integer, number of slices in an unrolled DBN
integer, number of static variables
an adjacency matrix of an unrolled DBN
# NOT RUN { compact2full(DBNmat, n.dynamic=12, n.slices=5, n.static=3) # }
Run the code above in your browser using DataLab