full2compact: Deriving a compact adjacency matrix of a DBN
Description
This function transforms an unrolled adjacency matrix of DBN into a compact representation
Usage
full2compact(DBNmat, n.dynamic, n.static = 0)
Arguments
DBNmat
a square matrix, representing the structure of an unrolled DBN; the size of matrix is n.slices*n.dynamic+n.static; all static variables are assumed to be in the first n.static rows and columns of the matrix
n.dynamic
integer, number of dynamic variables in each time slice