binary matrix (or a graph object) representing a 2-step DBN (compact or unrolled)
struct
option used to determine if the initial or the transition structure should be plotted; accaptable values are init or trans
n.dynamic
number of dynamic variables in one time slice of a DBN
n.static
number of static variables in one time slice of a DBN; note that for function to work correctly all static variables have to be in the first n.static columns of the matrix
Value
plots the DBN defined by the adjacency matrix 'DBN' and number of static and dynamic variables. When 'struct' equals "trans" the transition structure is plotted,
otherwise initial structure is plotted