This transforms a list of possible interactions between proteins downloaded from STRING database
into a matrix which can be used for blacklisting/penalization in BiDAG.
Usage
string2mat(curnames, mapping, int)
Arguments
curnames
character vector with gene names which will be used in BiDAG learning function
mapping
data frame, representing a mapping between curnames and preferredNames used in interactions downloaded from STRING (https://string-db.org/); two columns are necessary 'queryItem' and 'preferredName'
int
data frame, representing a interactions between genes/proteins downloaded from STRING (https://string-db.org/); two columns are necessary 'node1' and 'node2'
Value
square matrix, whose entries equal 1 is interactions between i and j is found in the interaction list and 0 otherwise